==> ideaIC-173.4301.1-sources.jar: com/intellij/openapi/vcs/configurable/VcsBackgroundOperationsConfigurable.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.vcs.configurable;


import com.intellij.openapi.options.ConfigurationException;
import com.intellij.openapi.options.SearchableConfigurable;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.Nls;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

public class VcsBackgroundOperationsConfigurable implements SearchableConfigurable {
  private VcsBackgroundOperationsConfigurationPanel myPanel;
  private final Project myProject;

  public VcsBackgroundOperationsConfigurable(Project project) {
    myProject = project;
  }

  @Override
  public void reset() {
    myPanel.reset();
  }

  @Override
  public void apply() throws ConfigurationException {
    myPanel.apply();
  }

  @Override
  public boolean isModified() {
    return myPanel.isModified();
  }

  @Nls
  public String getDisplayName() {
    return "Background";
  }

  @Override
  public String getHelpTopic() {
    return "project.propVCSSupport.Background";
  }

  @NotNull
  public String getId() {
    return getHelpTopic();
  }

  public JComponent createComponent() {
    myPanel = new VcsBackgroundOperationsConfigurationPanel(myProject);
    return myPanel.getPanel();
  }

  public void disposeUIResources() {
    myPanel = null;
  }

}

==> ideaIC-182.3208.16-sources.jar: com/intellij/openapi/vcs/configurable/VcsBackgroundOperationsConfigurable.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.vcs.configurable;


import com.intellij.openapi.options.ConfigurationException;
import com.intellij.openapi.options.SearchableConfigurable;
import com.intellij.openapi.project.Project;
import org.jetbrains.annotations.Nls;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;

public class VcsBackgroundOperationsConfigurable implements SearchableConfigurable {
  private VcsBackgroundOperationsConfigurationPanel myPanel;
  private final Project myProject;

  public VcsBackgroundOperationsConfigurable(Project project) {
    myProject = project;
  }

  @Override
  public void reset() {
    myPanel.reset();
  }

  @Override
  public void apply() throws ConfigurationException {
    myPanel.apply();
  }

  @Override
  public boolean isModified() {
    return myPanel != null && myPanel.isModified();
  }

  @Nls
  public String getDisplayName() {
    return "Background";
  }

  @Override
  public String getHelpTopic() {
    return "project.propVCSSupport.Background";
  }

  @NotNull
  public String getId() {
    return getHelpTopic();
  }

  public JComponent createComponent() {
    myPanel = new VcsBackgroundOperationsConfigurationPanel(myProject);
    return myPanel.getPanel();
  }

  public void disposeUIResources() {
    myPanel = null;
  }

}
